@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Manipulate the position of a note in a scale
 
-our $VERSION = '0.0600';
+our $VERSION = '0.0700';
 
 use Carp;
 use List::Util qw( first );
@@ -40,6 +40,12 @@ has offset => (
 );
 
 
+has flat => (
+    is      => 'ro',
+    default => sub { 0 },
+);
+
+
 has verbose => (
     is      => 'ro',
     default => sub { 0 },
@@ -52,6 +58,7 @@ sub get_offset {
     my $name   = $args{note_name};
     my $format = $args{note_format} || $self->note_format;
     my $offset = $args{offset} || $self->offset;
+    my $flat   = $args{flat} || $self->flat;
 
     croak 'note_name, note_format or offset not provided'
         unless $name || $format || $offset;
@@ -107,6 +114,10 @@ sub get_offset {
 
     $note = Music::Note->new( $scale[ $offset % @scale ] . $octave, 'ISO' );
 
+    if ( $flat && $note->format('isobase') =~ /#/ ) {
+        $note->en_eq('flat');
+    }
+
     warn sprintf "\tNew offset: %d, octave: %d, ISO: %s, Formatted: %s\n",
         $offset, $octave, $note->format('ISO'), $note->format($format)
         if $self->verbose;
@@ -120,6 +131,7 @@ sub step {
 
     my $name  = $args{note_name};
     my $steps = $args{steps} || 1;
+    my $flat  = $args{flat} || $self->flat;
 
     croak 'note_name not provided'
         unless $name;
@@ -129,6 +141,10 @@ sub step {
     $num += $steps;
     $note = Music::Note->new( $num, 'midinum' );
 
+    if ( $flat && $note->format('isobase') =~ /#/ ) {
+        $note->en_eq('flat');
+    }
+
     return $note;
 }
 
@@ -146,7 +162,7 @@ Music::ScaleNote - Manipulate the position of a note in a scale
 
 =head1 VERSION
 
-version 0.0600
+version 0.0700
 
 =head1 SYNOPSIS
 
@@ -178,6 +194,7 @@ version 0.0600
   $note = $msn->step(
     note_name => 'D3',
     steps     => -1,
+    flat      => 1,
   );
   print $note->format('ISO'), "\n"; # Db3
 
@@ -239,6 +256,13 @@ constructor, this is used in the B<get_offset> method.
 
 Default: C<1>
 
+=head2 flat
+
+Boolean indicating that we want a sharp resulting note flat instead.
+This exchanges a sharp note for its enharmonic equivalent flat.
+
+Default: C<0>
+
 =head2 verbose
 
 Show the progress of the B<get_offset> method.
@@ -257,6 +281,7 @@ Default: C<0>
     verbose     => $boolean,
     note_format => $format,
     offset      => $integer,
+    flat        => $flat,
   );
 
 Create a new C<Music::ScaleNote> object.
@@ -269,6 +294,7 @@ Create a new C<Music::ScaleNote> object.
     note_name   => $note_name,
     note_format => $format,
     offset      => $integer,
+    flat        => $flat,
   );
 
 Return a new L<Music::Note> object based on the required B<note_name>,
@@ -294,6 +320,7 @@ format and note name is B<not> how to use this module.
   $note = $msn->step(
     note_name => $note_name,
     steps     => $halfsteps,
+    flat      => $flat,
   );
 
 Return a new L<Music::Note> object based on the required B<note_name>
